package com.yuandian.dataflow.config;

import java.io.IOException;
import java.time.Instant;

import org.junit.Assert;
import org.junit.FixMethodOrder;
import org.junit.experimental.theories.suppliers.TestedOn;
import org.junit.jupiter.api.Order;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestMethodOrder;

import com.alibaba.nacos.api.exception.NacosException;

import lombok.extern.slf4j.Slf4j;

@Slf4j
public class ConfigTest {


    /**
     * 测试配置基础用法
     * @throws Exception
     */
    @Test
    @Order(1)
    void testUseConfig() throws Exception {
        Config.ENV_TEST = "-test";

        Config.UseConfig((cnf) -> {
			log.info("{}",cnf.data); 
            Assert.assertEquals(cnf.get("key1", "key2"), "key_path");
            Instant now = Instant.now();
			cnf.data.put("use_config", now.toString());
			try {
				log.info("{}",cnf.update());
			} catch (NacosException e) {
				e.printStackTrace();
			}
			return null;
		});
    }

    @Test
    @Order(2)
    void testRemove() throws Exception {
        Config.ENV_TEST = "-test";

        Config.UseConfig((cnf) -> {
            cnf.remove("create1", "create2");
			try {
				log.info("{}",cnf.update()); // 所有增加删除操作要最后同步到nacos. 都需要update
			} catch (NacosException e) {
				e.printStackTrace();
			}

            cnf.remove("create1");
			try {
				log.info("{}",cnf.update()); // 所有增加删除操作要最后同步到nacos. 都需要update
			} catch (NacosException e) {
				e.printStackTrace();
			}
            return null;
        });
    }


    @Test
    @Order(1)
    void testCreateKeys() throws Exception {
        Config.ENV_TEST = "-test";
 
        Config.UseConfig((cnf) -> {
			log.info("{}",cnf.data); 
            cnf.seek("create1", "create2", "create3").createKeys().set(Instant.now().toString());;
			try {
				log.info("{}",cnf.update()); // 所有增加删除操作要最后同步到nacos. 都需要update
			} catch (NacosException e) {
				e.printStackTrace();
			}
			return null;
		});
    }

  

    @Test
    void testUpdate() throws Exception {
        Config.ENV_TEST = "-test";

        Config.UseConfig((cnf) -> {
            Instant now = Instant.now();
			cnf.data.put("use_config", now.toString());
			try {
				log.info("{}",cnf.update());
			} catch (NacosException e) {
				e.printStackTrace();
			}
			return null;
		});
    }

    @Test
    void testLabelConfig() throws Exception {
        Config.UseConfig("org.fortest", (cnf)->{
            log.info("{}", cnf.get("test")); 
            Assert.assertEquals(cnf.get("test"),  "groupAndDataId"); 
            return null;
        });
    }
}
